我完全忘记了MySQL已经安装在这台特定的计算机上,我安装了MariaDB,我也不知道在同一台计算机上安装两个包的后果,我一直试图卸载这两个安装并消除它们的依赖关系。我在网上查找了几个关于如何做到这一点的教程,但我在运行MySQL时仍然有问题,在下面您会发现终端窗口的屏幕截图以及我尝试过的许多尝试解决方案的列表,不幸的是,我尝试了太多,以至于我无法回忆起我尝试过它们的顺序,我只想让MySQL的安装工作正常,但是不知怎么的,我无法从以前的安装中删除一些东西,并且MySQL安装不起作用,我得到了dpkg:警告。任何和所有的帮助将是非常感谢的。(Ubuntu 20.04)
这是终端窗口的屏幕截图。
homeserver@ubuserv:~/Desktop$ ps ax | grep mysql
4958 pts/0 S+ 0:00 grep --color=auto mysql
homeserver@ubuserv:~/Desktop$ sudo mysql_secure_installation utility
[sudo] password for homeserver:
Securing the MySQL server deployment.
Enter password for user root:
Error: Can't connect to local MySQL server through socket '/var/run/mysqld/mysqld.sock' (2)
homeserver@ubuserv:~/Desktop$ mysql --version
mysql Ver 8.0.20-0ubuntu0.20.04.1 for Linux on x86_64 ((Ubuntu))
homeserver@ubuserv:~/Desktop$ sudo systemctl stop mysql
Failed to stop mysql.service: Unit mysql.service not loaded.
homeserver@ubuserv:~/Desktop$ sudo systemctl stop mysql
Failed to stop mysql.service: Unit mysql.service not loaded.
homeserver@ubuserv:~/Desktop$ mysql -u root
ERROR 2002 (HY000): Can't connect to local MySQL server through socket '/var/run/mysqld/mysqld.sock' (2)
homeserver@ubuserv:~/Desktop$ sudo apt install synaptic
Reading package lists... Done
Building dependency tree
Reading state information... Done
synaptic is already the newest version (0.84.6ubuntu5).
The following packages were automatically installed and are no longer required:
hplip-data printer-driver-postscript-hp python3-renderpm
python3-reportlab python3-reportlab-accel
Use 'sudo apt autoremove' to remove them.
0 upgraded, 0 newly installed, 0 to remove and 10 not upgraded.
homeserver@ubuserv:~/Desktop$ sudo service mysql restart
[sudo] password for homeserver:
Failed to restart mysql.service: Unit mysql.service not found.
homeserver@ubuserv:~/Desktop$ apt search mysql | grep "\[install"
WARNING: apt does not have a stable CLI interface. Use with caution in scripts.
libdbi-perl/focal,now 1.643-1 amd64 [installed]
libmysqlclient21/focal-updates,focal-security,now 8.0.20-0ubuntu0.20.04.1 amd64 [installed]
librdf0/focal,now 1.0.17-1.1ubuntu1 amd64 [installed,automatic]
mysql-client-8.0/focal-updates,focal-security,now 8.0.20-0ubuntu0.20.04.1 amd64 [installed]
mysql-client-core-8.0/focal-updates,focal-security,now 8.0.20-0ubuntu0.20.04.1 amd64 [installed]
mysql-common/focal,focal,now 5.8+1.0.5ubuntu2 all [installed]
mysql-server/focal-updates,focal-updates,focal-security,focal-security,now 8.0.20-0ubuntu0.20.04.1 all [installed]
mysql-server-8.0/focal-updates,focal-security,now 8.0.20-0ubuntu0.20.04.1 amd64 [installed]
mysql-server-core-8.0/focal-updates,focal-security,now 8.0.20-0ubuntu0.20.04.1 amd64 [installed]
rsyslog/focal,now 8.2001.0-1ubuntu1 amd64 [installed,automatic]
homeserver@ubuserv:~/Desktop$ sudo apt -f install mysql-server
[sudo] password for homeserver:
Reading package lists... Done
Building dependency tree
Reading state information... Done
mysql-server is already the newest version (8.0.20-0ubuntu0.20.04.1).
0 upgraded, 0 newly installed, 0 to remove and 10 not upgraded.
homeserver@ubuserv:~/Desktop$ sudo apt -f install mysql-client
Reading package lists... Done
Building dependency tree
Reading state information... Done
The following NEW packages will be installed:
mysql-client
0 upgraded, 1 newly installed, 0 to remove and 10 not upgraded.
Need to get 9.424 B of archives.
After this operation, 110 kB of additional disk space will be used.
Get:1 http://archive.ubuntu.com/ubuntu focal-updates/main amd64 mysql-client all 8.0.20-0ubuntu0.20.04.1 [9.424 B]
Fetched 9.424 B in 1s (14,4 kB/s)
Selecting previously unselected package mysql-client.
dpkg: warning: files list file for package 'mysql-server-8.0' missing; assuming package has no files currently installed
dpkg: warning: files list file for package 'mysql-common' missing; assuming package has no files currently installed
dpkg: warning: files list file for package 'mysql-client-core-8.0' missing; assuming package has no files currently installed
dpkg: warning: files list file for package 'mysql-server-core-8.0' missing; assuming package has no files currently installed
dpkg: warning: files list file for package 'mysql-client-8.0' missing; assuming package has no files currently installed
(Reading database ... 223970 files and directories currently installed.)
Preparing to unpack .../mysql-client_8.0.20-0ubuntu0.20.04.1_all.deb ...
Unpacking mysql-client (8.0.20-0ubuntu0.20.04.1) ...
Setting up mysql-client (8.0.20-0ubuntu0.20.04.1) ...
homeserver@ubuserv:~/Desktop$ dir
homeserver@ubuserv:~/Desktop$ cd ..
homeserver@ubuserv:~$ dir
Desktop Documents Downloads Music Pictures Public snap Templates Videos
homeserver@ubuserv:~$ cd Downloads
homeserver@ubuserv:~/Downloads$ dir
bprocessor-M11.zip ClientBridgeWorking.bin RepeaterBridgeWorking3.bin
ClientBridgeWorking2.bin mysql-apt-config_0.8.15-1_all.deb teamviewer_15.5.3_amd64.deb
homeserver@ubuserv:~/Downloads$ sudo dpkg -i mysql-apt-config_0.8.15-1_all.deb
Selecting previously unselected package mysql-apt-config.
dpkg: warning: files list file for package 'mysql-server-8.0' missing; assuming package has no files currently installed
dpkg: warning: files list file for package 'mysql-common' missing; assuming package has no files currently installed
dpkg: warning: files list file for package 'mysql-client-core-8.0' missing; assuming package has no files currently installed
dpkg: warning: files list file for package 'mysql-server-core-8.0' missing; assuming package has no files currently installed
dpkg: warning: files list file for package 'mysql-client-8.0' missing; assuming package has no files currently installed
(Reading database ... 223974 files and directories currently installed.)
Preparing to unpack mysql-apt-config_0.8.15-1_all.deb ...
Unpacking mysql-apt-config (0.8.15-1) ...
Setting up mysql-apt-config (0.8.15-1) ...
Warning: apt-key should not be used in scripts (called from postinst maintainerscript of the package mysql-apt-config)
OK
homeserver@ubuserv:~/Downloads$ sudo service mysql status
Unit mysql.service could not be found.
homeserver@ubuserv:~/Downloads$ sudo service mysql start
Failed to start mysql.service: Unit mysql.service not found.
homeserver@ubuserv:~/Downloads$ sudo dpkg -P mysql
dpkg: warning: ignoring request to remove mysql which isn't installed
homeserver@ubuserv:~/Downloads$ sudo apt-get install --reinstall mysql-server
Reading package lists... Done
Building dependency tree
Reading state information... Done
0 upgraded, 0 newly installed, 1 reinstalled, 0 to remove and 10 not upgraded.
Need to get 9.540 B of archives.
After this operation, 0 B of additional disk space will be used.
Get:1 http://archive.ubuntu.com/ubuntu focal-updates/main amd64 mysql-server all 8.0.20-0ubuntu0.20.04.1 [9.540 B]
Fetched 9.540 B in 1s (17,6 kB/s)
dpkg: warning: files list file for package 'mysql-server-8.0' missing; assuming package has no files currently installed
dpkg: warning: files list file for package 'mysql-common' missing; assuming package has no files currently installed
dpkg: warning: files list file for package 'mysql-client-core-8.0' missing; assuming package has no files currently installed
dpkg: warning: files list file for package 'mysql-server-core-8.0' missing; assuming package has no files currently installed
dpkg: warning: files list file for package 'mysql-client-8.0' missing; assuming package has no files currently installed
(Reading database ... 223979 files and directories currently installed.)
Preparing to unpack .../mysql-server_8.0.20-0ubuntu0.20.04.1_all.deb ...
Unpacking mysql-server (8.0.20-0ubuntu0.20.04.1) over (8.0.20-0ubuntu0.20.04.1) ...
Setting up mysql-server (8.0.20-0ubuntu0.20.04.1) ...SU终端
homeserver@ubuserv:~/Desktop$ mysql -u root
ERROR 2002 (HY000): Can't connect to local MySQL server through socket '/var/run/mysqld/mysqld.sock' (2)
homeserver@ubuserv:~/Desktop$ sudo apt install synaptic
Reading package lists... Done
Building dependency tree
Reading state information... Done
synaptic is already the newest version (0.84.6ubuntu5).
The following packages were automatically installed and are no longer required:
hplip-data printer-driver-postscript-hp python3-renderpm
python3-reportlab python3-reportlab-accel
Use 'sudo apt autoremove' to remove them.
0 upgraded, 0 newly installed, 0 to remove and 10 not upgraded.
homeserver@ubuserv:~/Desktop$ synaptic
homeserver@ubuserv:~/Desktop$ sudo su
root@ubuserv:/home/homeserver/Desktop# synaptic
root@ubuserv:/home/homeserver/Desktop# gksu synaptic
Command 'gksu' not found, did you mean:
command 'gosu' from deb gosu (1.10-1)
command 'ksu' from deb heimdal-clients (7.7.0+dfsg-1ubuntu1)
command 'ksu' from deb krb5-user (1.17-6ubuntu4)
Try: apt install
root@ubuserv:/home/homeserver/Desktop# gksu synaptic
Command 'gksu' not found, did you mean:
command 'ksu' from deb heimdal-clients (7.7.0+dfsg-1ubuntu1)
command 'ksu' from deb krb5-user (1.17-6ubuntu4)
command 'gosu' from deb gosu (1.10-1)
Try: apt install
root@ubuserv:/home/homeserver/Desktop# synaptic admin://
root@ubuserv:/home/homeserver/Desktop# xhost +si:localuser:root
localuser:root being added to access control list
root@ubuserv:/home/homeserver/Desktop# synaptic
^C
root@ubuserv:/home/homeserver/Desktop# synaptic
root@ubuserv:/home/homeserver/Desktop# synaptic
root@ubuserv:/home/homeserver/Desktop# synaptic
^C
root@ubuserv:/home/homeserver/Desktop# synaptic
root@ubuserv:/home/homeserver/Desktop# synaptic
root@ubuserv:/home/homeserver/Desktop# cd..
cd..: command not found
root@ubuserv:/home/homeserver/Desktop# cd ..
root@ubuserv:/home/homeserver# cd ..
root@ubuserv:/home# cd ..
root@ubuserv:/# cd ..
root@ubuserv:/# dir
bin dev lib libx32 mnt root snap sys var
boot etc lib32 lost+found opt run srv tmp
cdrom home lib64 media proc sbin swapfile usr
root@ubuserv:/# sudo aptitude install mysql-server
sudo: aptitude: command not found
root@ubuserv:/# sudo apt install mysql-server
Reading package lists... Done
Building dependency tree
Reading state information... Done
mysql-server is already the newest version (8.0.20-0ubuntu0.20.04.1).
0 upgraded, 0 newly installed, 0 to remove and 10 not upgraded.
root@ubuserv:/# 在终端发出的命令
$ sudo apt install mysql-server
$ sudo mysql_secure_installation
$ sudo mysql
$ sudo apt remove mysql-server
$ sudo apt install mariadb-server
$ sudo nano /etc/mysql/mariadb.conf.d/50-server.cnf
$ sudo service mysql restart
$ sudo service mysql stop
$ sudo service mysql start
$ systemctl status mariadb.service
$ set mysql/config/mysqld/innodb_force_recovery=1
$ systemctl start mariadb
$ find /etc -name *.cnf
$ sudo apt-get purge mariadb-server
$ sudo dpkg -l | grep mariadb
$ sudo nano /etc/mysql/debian.cnf
$ sudo mysql_secure_installation
$ apt-get purge mysql-server\*
$ rm -rf /etc/my.cnf /etc/mysql
$ sudo apt-get remove --purge mysql*
$ sudo apt-get purge mysql*
$ sudo apt-get autoclean
$ sudo apt-get remove dbconfig-mysql
$ sudo apt-get remove ––purge mariadb-server
$ del mysql*
$ rm mysql*
$ sudo apt-get clean
$ ps -A|grep mysql
$ sudo pkill mysql
$ ps -A|grep mysqld
$ ps ax | grep mysql
$ sudo nano sources.list
$ sudo apt purge mariadb-*
$ sudo rm -rf /usr/share/mysql/
$ find mariadb.repo
$ find mariadb*
$ apt search mysql | grep "\[install"
$ sudo apt -f install mysql-server
$ sudo dpkg -i mysql-apt-config_0.8.15-1_all.deb作为SU发出的命令
# service mysql stop
# killall -KILL mysql mysqld_safe mysqld
# apt-get --yes purge mysql-server mysql-client
# apt-get --yes autoremove --purge
# apt-get autoclean
# deluser --remove-home mysql
# delgroup mysql
# rm -rf /etc/apparmor.d/abstractions/mysql /etc/apparmor.d/cache/usr.sbin.mysqld /etc/mysql /var/lib/mysql /var/log/mysql* /var/log/upstart/mysql.log* /var/run/mysqld
# updatedb
# rm ~/.mysql_history
# sudo apt-get purge mariadb-server
# sudo dpkg -l | grep mariadb
# sudo apt-get purge mariadb-server
# sudo dpkg -l | grep mariadb
# edit /etc/mysql/mysql.conf.d/mysqld.cnf
# killall -KILL mysql mysqld_safe mysqld
# apt-get --yes purge mysql-server mysql-client
# apt-get --yes autoremove --purge
# apt-get autoclean
# deluser --remove-home mysql
# delgroup mysql
# apt-get remove --purge mariadb
# apt-get remove --purge mariadb*
# sudo rm -rf /etc/mysql/
# sudo apt install mysql-server
# sudo apt-get autoclean && sudo apt-get --force-yes remove mysql-community-server-dbgsym mysql-community-server mysql-server
# xhost +si:localuser:root
# synaptic更新
我在突触中删除了Libmysqlclient21,因为它出现故障,我试图从synaptic中成功地卸载MySQL,并从synaptic中重新安装它,显然我找不到正在运行的MySQL进程,这阻止了mysql 8.0 (mysql-client,client-8.0,client-core-8.0,服务器和服务器-8.0重新安装)的安装。接下来您将发现屏幕截图https://pastebin.ubuntu.com/p/pJCxYm5K2w/
还有
internal Error, No file name for mysql-server:amd64发布于 2020-05-28 03:07:57
我不明白发生了什么,我是通过一个拥有完全管理权限的用户帐户远程访问ubuntu机器,但它不是在安装ubuntu时创建的帐户,现在我终于直接访问了计算机并使用原始帐户登录,这让我很惊讶,当我试图通过突触卸载所有MySQL时,我根本没有收到警告或错误,只是为了安全起见,我运行以下命令
# sudo apt-get remove --purge mysql-server mysql-client mysql-common -y
# sudo apt-get autoremove -y
# rm -rf /etc/mysql
# sudo find / -iname 'mysql*' -exec rm -rf {} \;
# apt --fix-broken install没有任何错误或警告,所以我启动了synaptic并重新安装了mysql-server (synaptic负责处理依赖项),并正确地完成了安装。这对我来说没有任何意义,因为拥有完全管理权限的用户帐户应该有完全的访问权限,但是在那里,MySQL已经安装并运行。
发布于 2020-05-25 22:54:28
好的,看起来MySQL APT存储库提供了mysql-common,所以卸载所有本机8.0版本,但是他们建议您不要在这里清除,只需卸载:
sudo apt remove mysql-client-core-8.0 mysql-server-core-8.0 mysql-server-8.0 mysql-client-core-8.0 mysql-client-8.0 然后,您应该能够完成安装:
sudo apt install --reinstall -o Dpkg::Options::="--force-confmiss" mysql-community-client-core mysql-community-server-core mysql-common mysql-client mysql-server 最后,可以通过运行以下命令更新共享库:
sudo apt install libmysqlclient21这将取代现有的版本。
可用包列表和更多信息可以找到这里。
https://askubuntu.com/questions/1243650
复制相似问题